<!DOCTYPE html>
<html lang="en">


<!-- Mirrored from bracketweb.com/ienet-html-main/index-3.html by HTTrack Website Copier/3.x [XR&CO'2014], Thu, 13 Mar 2025 09:04:05 GMT -->
<head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title>Home Three || Ienet || HTML Template For Broadband TV & Internet</title>
    <!-- favicons Icons -->
    <link rel="apple-touch-icon" sizes="180x180" href="assets/images/favicons/apple-touch-icon.png" />
    <link rel="icon" type="image/png" sizes="32x32" href="assets/images/favicons/favicon-32x32.png" />
    <link rel="icon" type="image/png" sizes="16x16" href="assets/images/favicons/favicon-16x16.png" />
    <link rel="manifest" href="assets/images/favicons/site.webmanifest" />
    <meta name="description" content="Ienet is a multipurpose & unique HTML5 template. We especially designed for broadband internet services, satellite TV, Broadband, Online TV, Cable Television, Online Cinema and Movies, Voip, Wifi, Internet and TV store, Digital TV, Computer Networks, IPTV, Telecom company, CCTV and alternative Security, Networking Solution technology and all other internet businesses and websites." />

    <!-- fonts -->
    <link rel="preconnect" href="https://fonts.googleapis.com/">
    <link rel="preconnect" href="https://fonts.gstatic.com/" crossorigin>
    <link href="https://fonts.googleapis.com/css2?family=Outfit:wght@100..900&amp;display=swap" rel="stylesheet">


    <link rel="stylesheet" href="assets/vendors/bootstrap/css/bootstrap.min.css" />
    <link rel="stylesheet" href="assets/vendors/bootstrap-select/bootstrap-select.min.css" />
    <link rel="stylesheet" href="assets/vendors/animate/animate.min.css" />
    <link rel="stylesheet" href="assets/vendors/fontawesome/css/all.min.css" />
    <link rel="stylesheet" href="assets/vendors/jquery-ui/jquery-ui.css" />
    <link rel="stylesheet" href="assets/vendors/jarallax/jarallax.css" />
    <link rel="stylesheet" href="assets/vendors/jquery-magnific-popup/jquery.magnific-popup.css" />
    <link rel="stylesheet" href="assets/vendors/nouislider/nouislider.min.css" />
    <link rel="stylesheet" href="assets/vendors/nouislider/nouislider.pips.css" />
    <link rel="stylesheet" href="assets/vendors/tiny-slider/tiny-slider.css" />
    <link rel="stylesheet" href="assets/vendors/ienet-icons/style.css" />
    <link rel="stylesheet" href="assets/vendors/slick/slick.css">
    <link rel="stylesheet" href="assets/vendors/owl-carousel/css/owl.carousel.min.css" />
    <link rel="stylesheet" href="assets/vendors/owl-carousel/css/owl.theme.default.min.css" />

    <!-- template styles -->
    <link rel="stylesheet" href="assets/css/ienet.css" />
</head>

<body class="custom-cursor">

    <div class="custom-cursor__cursor"></div>
    <div class="custom-cursor__cursor-two"></div>

    <div class="preloader">
        <div class="preloader__image" style="background-image: url(assets/images/loader.png);"></div>
    </div>
    <!-- /.preloader -->
    <div class="page-wrapper">
        <header class="main-header main-header--three sticky-header sticky-header--normal">
            <div class="container-fluid">
                <div class="main-header__inner">
                    <div class="main-header__logo">
                        <a href="index.html">
                            <img src="assets/images/logo-dark.png" alt="Ienet HTML" height="60">
                        </a>
                    </div><!-- /.main-header__logo -->
                    <nav class="main-header__nav main-menu">
                        <ul class="main-menu__list">


                            <li class="megamenu megamenu-clickable megamenu-clickable--toggler">
                                <a href="index.html">Demos</a>
                                <ul>
                                    <li>
                                        <div class="megamenu-popup">
                                            <a href="#" class="megamenu-clickable--close"><span class="icon-close"></span></a>
                                            <!-- /.megamenu-clickable--close -->
                                            <div class="megamenu-popup__content">
                                                <div class="demo-one">
                                                    <div class="container">
                                                        <div class="row">
                                                            <div class="col-md-6 col-lg-4">
                                                                <div class="demo-one__card">
                                                                    <div class="demo-one__image">
                                                                        <img src="assets/images/landing/home-1.jpg" alt="ienet">
                                                                        <div class="demo-one__btns">
                                                                            <a href="index.html" class="ienet-btn demo-one__btn">
                                                                                <span>Multi Page</span>
                                                                            </a><!-- /.thm-btn demo-one__btn -->
                                                                            <a href="index-one-page.html" class="ienet-btn demo-one__btn">
                                                                                <span>One Page</span>
                                                                            </a><!-- /.thm-btn demo-one__btn -->
                                                                        </div><!-- /.demo-one__btns -->
                                                                    </div><!-- /.demo-one__image -->
                                                                    <div class="demo-one__content">
                                                                        <h3 class="demo-one__title">
                                                                            <a href="index.html">Home Page 01</a>
                                                                        </h3><!-- /.demo-one__title -->
                                                                    </div><!-- /.demo-one__content -->
                                                                </div><!-- /.demo-one__card -->
                                                            </div><!-- /.col-md-6 col-lg-3 -->
                                                            <div class="col-md-6 col-lg-4">
                                                                <div class="demo-one__card">
                                                                    <div class="demo-one__image">
                                                                        <img src="assets/images/landing/home-2.jpg" alt="ienet">
                                                                        <div class="demo-one__btns">
                                                                            <a href="index-2.html" class="ienet-btn demo-one__btn">
                                                                                <span>Multi Page</span>
                                                                            </a><!-- /.thm-btn demo-one__btn -->
                                                                            <a href="index-2-one-page.html" class="ienet-btn demo-one__btn">
                                                                                <span>One Page</span>
                                                                            </a><!-- /.thm-btn demo-one__btn -->
                                                                        </div><!-- /.demo-one__btns -->
                                                                    </div><!-- /.demo-one__image -->
                                                                    <div class="demo-one__content">
                                                                        <h3 class="demo-one__title">
                                                                            <a href="index-2.html">Home Page 02</a>
                                                                        </h3><!-- /.demo-one__title -->
                                                                    </div><!-- /.demo-one__content -->
                                                                </div><!-- /.demo-one__card -->
                                                            </div><!-- /.col-md-6 col-lg-3 -->
                                                            <div class="col-md-6 col-lg-4">
                                                                <div class="demo-one__card">
                                                                    <div class="demo-one__image">
                                                                        <img src="assets/images/landing/home-3.jpg" alt="ienet">
                                                                        <div class="demo-one__btns">
                                                                            <a href="index-3.html" class="ienet-btn demo-one__btn">
                                                                                <span>Multi Page</span>
                                                                            </a><!-- /.thm-btn demo-one__btn -->
                                                                            <a href="index-3-one-page.html" class="ienet-btn demo-one__btn">
                                                                                <span>One Page</span>
                                                                            </a><!-- /.thm-btn demo-one__btn -->
                                                                        </div><!-- /.demo-one__btns -->
                                                                    </div><!-- /.demo-one__image -->
                                                                    <div class="demo-one__content">
                                                                        <h3 class="demo-one__title">
                                                                            <a href="index-3.html">Home Page 03</a>
                                                                        </h3><!-- /.demo-one__title -->
                                                                    </div><!-- /.demo-one__content -->
                                                                </div><!-- /.demo-one__card -->
                                                            </div><!-- /.col-md-6 col-lg-3 -->
                                                            <div class="col-md-6 col-lg-4">
                                                                <div class="demo-one__card">
                                                                    <div class="demo-one__image">
                                                                        <img src="assets/images/landing/home-dark.jpg" alt="ienet">
                                                                        <div class="demo-one__btns">
                                                                            <a href="index-dark.html" class="ienet-btn demo-one__btn">
                                                                                <span>View Page</span>
                                                                            </a><!-- /.thm-btn demo-one__btn -->
                                                                        </div><!-- /.demo-one__btns -->
                                                                    </div><!-- /.demo-one__image -->
                                                                    <div class="demo-one__content">
                                                                        <h3 class="demo-one__title">
                                                                            <a href="index-dark.html">Home Dark</a>
                                                                        </h3><!-- /.demo-one__title -->
                                                                    </div><!-- /.demo-one__content -->
                                                                </div><!-- /.demo-one__card -->
                                                            </div><!-- /.col-md-6 col-lg-3 -->
                                                            <div class="col-md-6 col-lg-4">
                                                                <div class="demo-one__card">
                                                                    <div class="demo-one__image">
                                                                        <img src="assets/images/landing/home-boxed.jpg" alt="ienet">
                                                                        <div class="demo-one__btns">
                                                                            <a href="index-boxed.html" class="ienet-btn demo-one__btn">
                                                                                <span>View Page</span>
                                                                            </a><!-- /.thm-btn demo-one__btn -->
                                                                        </div><!-- /.demo-one__btns -->
                                                                    </div><!-- /.demo-one__image -->
                                                                    <div class="demo-one__content">
                                                                        <h3 class="demo-one__title">
                                                                            <a href="index-boxed.html">Home Boxed</a>
                                                                        </h3><!-- /.demo-one__title -->
                                                                    </div><!-- /.demo-one__content -->
                                                                </div><!-- /.demo-one__card -->
                                                            </div><!-- /.col-md-6 col-lg-3 -->
                                                            <div class="col-md-6 col-lg-4">
                                                                <div class="demo-one__card">
                                                                    <div class="demo-one__image">
                                                                        <img src="assets/images/landing/home-rtl.jpg" alt="ienet">
                                                                        <div class="demo-one__btns">
                                                                            <a href="index-rtl.html#googtrans(en%7car)" class="ienet-btn demo-one__btn">
                                                                                <span>View Page</span>
                                                                            </a><!-- /.thm-btn demo-one__btn -->
                                                                        </div><!-- /.demo-one__btns -->
                                                                    </div><!-- /.demo-one__image -->
                                                                    <div class="demo-one__content">
                                                                        <h3 class="demo-one__title">
                                                                            <a href="index-rtl.html#googtrans(en%7car)">Home RTL</a>
                                                                        </h3><!-- /.demo-one__title -->
                                                                    </div><!-- /.demo-one__content -->
                                                                </div><!-- /.demo-one__card -->
                                                            </div><!-- /.col-md-6 col-lg-3 -->
                                                        </div><!-- /.row -->
                                                    </div><!-- /.container -->
                                                </div><!-- /.demos-one -->
                                            </div><!-- /.megamenu-popup__content -->
                                        </div><!-- /.megamenu-popup -->
                                    </li>
                                </ul>
                            </li>


                            <li>
                                <a href="about.html">About</a>
                            </li>
                            <li class="dropdown">
                                <a href="#">Pages</a>
                                <ul>
                                    <li class="dropdown">
                                        <a href="#">Movies</a>
                                        <ul class="sub-menu">
                                            <li><a href="movie.html">Movies Page</a></li>
                                            <li><a href="movie-carousel.html">Movies Carousel</a></li>
                                            <li><a href="movie-details.html">Movies Details</a></li>
                                        </ul>
                                    </li>
                                    <li class="dropdown">
                                        <a href="#">Teams</a>
                                        <ul class="sub-menu">
                                            <li><a href="team.html">Our Team</a></li>
                                            <li><a href="team-carousel.html">Team Carousel</a></li>
                                            <li><a href="team-details.html">Team Details</a></li>
                                        </ul>
                                    </li>
                                    <li><a href="reviews.html">Testimonials</a></li>
                                    <li><a href="reviews-carousel.html">Testimonials Carousel</a></li>
                                    <li><a href="packages.html">Pricing Page</a></li>
                                    <li><a href="packages-carousel.html">Pricing Carousel</a></li>
                                    <li>
                                        <a href="gallery.html">Gallery</a>
                                        <ul>
                                            <li><a href="gallery.html">Gallery Masonry</a></li>
                                            <li><a href="gallery-filter.html">Gallery Filter</a></li>
                                            <li><a href="gallery-grid.html">Gallery Grid</a></li>
                                            <li><a href="gallery-carousel.html">Gallery Carousel</a></li>
                                        </ul>
                                    </li>
                                    <li><a href="faq.html">FAQs</a></li>
                                    <li><a href="login.html">Login</a></li>
                                    <li><a href="404.html">404 Error</a></li>
                                </ul>
                            </li>
                            <li class="dropdown">
                                <a href="#">Services</a>
                                <ul>
                                    <li><a href="services.html">Services</a></li>
                                    <li><a href="services-carousel.html">Services Carousel</a></li>
                                    <li><a href="service-d-broadband.html">Fiber & Broadband Line</a></li>
                                    <li><a href="service-d-iptv.html">Fiber Line Smart IPTV</a></li>
                                    <li><a href="service-d-cyber-security.html">Internet & Cyber Security</a></li>
                                    <li><a href="service-d-landline.html">Optical Fiber & Landline</a></li>
                                    <li><a href="service-d-tv.html">Amazon Fire Stick Box TV</a></li>
                                    <li><a href="service-d-connectivity.html">Smart Data Connectivity</a></li>
                                </ul>
                            </li>

                            <li class="dropdown">
                                <a href="#">Shop</a>
                                <ul class="sub-menu">
                                    <li class="dropdown">
                                        <a href="#">Products</a>
                                        <ul class="sub-menu">
                                            <li><a href="products.html">No Sidebar</a></li>
                                            <li><a href="products-left.html">Left Sidebar</a></li>
                                            <li><a href="products-right.html">Right Sidebar</a></li>
                                        </ul>
                                    </li>
                                    <li><a href="products-carousel.html">Products Carousel</a></li>
                                    <li><a href="product-details.html">Product Details</a></li>
                                    <li><a href="cart.html">Cart</a></li>
                                    <li><a href="checkout.html">Checkout</a></li>
                                </ul>
                            </li>
                            <li class="dropdown">
                                <a href="#">News</a>
                                <ul class="sub-menu">
                                    <li class="dropdown">
                                        <a href="#">News grid</a>
                                        <ul class="sub-menu">
                                            <li><a href="blog-grid.html">No Sidebar</a></li>
                                            <li><a href="blog-grid-left.html">Left Sidebar</a></li>
                                            <li><a href="blog-grid-right.html">Right Sidebar</a></li>
                                        </ul>
                                    </li>
                                    <li class="dropdown">
                                        <a href="#">News list</a>
                                        <ul class="sub-menu">
                                            <li><a href="blog-list.html">No Sidebar</a></li>
                                            <li><a href="blog-list-left.html">Left Sidebar</a></li>
                                            <li><a href="blog-list-right.html">Right Sidebar</a></li>
                                        </ul>
                                    </li>
                                    <li><a href="blog-carousel.html">News Carousel</a></li>
                                    <li class="dropdown">
                                        <a href="#">News Details</a>
                                        <ul class="sub-menu">
                                            <li><a href="blog-details.html">No Sidebar</a></li>
                                            <li><a href="blog-details-left.html">Left Sidebar</a></li>
                                            <li><a href="blog-details-right.html">Right Sidebar</a></li>
                                        </ul>
                                    </li>
                                </ul>
                            </li>
                            <li>
                                <a href="contact.html">Contact</a>
                            </li>
                        </ul>
                    </nav><!-- /.main-header__nav -->
                    <div class="main-header__right">
                        <div class="mobile-nav__btn mobile-nav__toggler">
                            <span></span>
                            <span></span>
                            <span></span>
                        </div><!-- /.mobile-nav__toggler -->
                        <a href="#" class="search-toggler main-header__search">
                            <i class="icon-search" aria-hidden="true"></i>
                            <span class="sr-only">Search</span>
                        </a><!-- /.search-toggler -->
                        <a href="cart.html" class="main-header__cart">
                            <i class="icon-cart" aria-hidden="true"></i>
                            <span class="sr-only">Cart</span>
                        </a><!-- /.cart-toggler -->
                        <div class="main-header__call">
                            <div class="main-header__call__icon"><span class="icon-telephone"></span></div>
                            <div class="main-header__call__title">Call Emergency</div>
                            <a class="main-header__call__text" href="tel:88012365499">+88 0123 654 99</a>
                        </div><!-- /.info -->
                        <a href="contact.html" class="ienet-btn"><span>GET IN TOUCH<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                        <a href="#" class="main-header__toggler"><span class="icon-menu"></span></a><!-- /.sidebar-toggler -->
                        <!-- /.main-header__btn -->
                    </div>
                </div><!-- /.main-header__inner -->
            </div><!-- /.container-fluid -->
        </header><!-- /.main-header -->

        <!-- main-slider-start -->
        <section class="main-slider-three">
            <div class="main-slider-three__carousel ienet-owl__carousel owl-carousel" data-owl-options='{
		"loop": true,
		"animateOut": "fadeOut",
		"animateIn": "fadeIn",
		"items": 1,
		"autoplay": true,
		"autoplayTimeout": 7000,
		"smartSpeed": 1000,
		"nav": false,
        "navText": ["<span class=\"icon-left-arrow\"></span>","<span class=\"icon-right-arrow\"></span>"],
		"dots": true,
		"margin": 0
	    }'>
                <div class="item">
                    <div class="main-slider-three__item">
                        <div class="main-slider-three__bg" style="background-image: url(assets/images/shapes/slider-3-1.png);">
                            <div class="main-slider-four__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                        </div>
                        <div class="main-slider-three__shape-one">
                            <img src="assets/images/shapes/slider-3-shape-1.png" alt="ienet">
                        </div>
                        <div class="main-slider-three__shape-two">
                            <img src="assets/images/resources/slider-3-shape-2.png" alt="ienet">
                        </div>
                        <div class="main-slider-three__content">
                            <h5 class="main-slider-three__sub-title">We make the web a better place!</h5>
                            <!-- slider-sub-title -->
                            <h2 class="main-slider-three__title">Best <span>Internet</span><br> Service Provider<br> In Your
                                Region</h2><!-- slider-title -->
                            <p class="main-slider-three__text">
                                Donec pretium ornare neque, ac luctus orci ultrices at. Sed blandit<br> eleifend mi, a
                                consectetur tortor varius in.
                                Sed tincidunt aliquet lorem,<br> eget tincidunt est molestie non. 
                            </p><!-- slider-tex -->
                            <div class="main-slider-three__btn">
                                <a href="services.html" class="ienet-btn main-slider-three__btn__first"><span>our service<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                                <!-- slider-btn -->
                                <a href="contact.html" class="ienet-btn main-slider-three__btn__last"><span><span class="ienet-btn__icon ienet-btn__icon--left"><i class="fas fa-gem"></i></span>Contact Now</span></a><!-- slider-btn -->
                            </div>
                        </div>
                        <div class="main-slider-three__image">
                            <div class="main-slider-three__layer-bg"></div>
                            <div class="main-slider-three__layer" style="background-image: url(assets/images/backgrounds/slider-3-layer-1.jpg);"></div>
                            <div class="main-slider-three__price">start form<br> <span>$39 /</span> month</div>
                            <div class="main-slider-three__layer-shape"></div>
                            <div class="main-slider-three__layer-shape-two">
                                <img src="assets/images/shapes/slider-3-shape-3.png" alt="ienet">
                            </div>
                        </div>
                    </div>
                </div>
                <div class="item">
                    <div class="main-slider-three__item">
                        <div class="main-slider-three__bg" style="background-image: url(assets/images/shapes/slider-3-1.png);">
                            <div class="main-slider-four__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                        </div>
                        <div class="main-slider-three__shape-one">
                            <img src="assets/images/shapes/slider-3-shape-1.png" alt="ienet">
                        </div>
                        <div class="main-slider-three__shape-two">
                            <img src="assets/images/resources/slider-3-shape-2.png" alt="ienet">
                        </div>
                        <div class="main-slider-three__content">
                            <h5 class="main-slider-three__sub-title">We make the web a better place!</h5>
                            <!-- slider-sub-title -->
                            <h2 class="main-slider-three__title">Best <span>Internet</span><br> Service Provider<br> In Your
                                Region</h2><!-- slider-title -->
                            <p class="main-slider-three__text">
                                Donec pretium ornare neque, ac luctus orci ultrices at. Sed blandit<br> eleifend mi, a
                                consectetur tortor varius in.
                                Sed tincidunt aliquet lorem,<br> eget tincidunt est molestie non. 
                            </p><!-- slider-tex -->
                            <div class="main-slider-three__btn">
                                <a href="services.html" class="ienet-btn main-slider-three__btn__first"><span>our service<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                                <!-- slider-btn -->
                                <a href="contact.html" class="ienet-btn main-slider-three__btn__last"><span><span class="ienet-btn__icon ienet-btn__icon--left"><i class="fas fa-gem"></i></span>Contact Now</span></a><!-- slider-btn -->
                            </div>
                        </div>
                        <div class="main-slider-three__image">
                            <div class="main-slider-three__layer-bg"></div>
                            <div class="main-slider-three__layer" style="background-image: url(assets/images/backgrounds/slider-3-layer-2.jpg);"></div>
                            <div class="main-slider-three__price">start form<br> <span>$39 /</span> month</div>
                            <div class="main-slider-three__layer-shape"></div>
                            <div class="main-slider-three__layer-shape-two">
                                <img src="assets/images/shapes/slider-3-shape-3.png" alt="ienet">
                            </div>
                        </div>
                    </div>
                </div>
                <div class="item">
                    <div class="main-slider-three__item">
                        <div class="main-slider-three__bg" style="background-image: url(assets/images/shapes/slider-3-1.png);">
                            <div class="main-slider-four__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                            <div class="main-slider-three__bg__color"></div>
                        </div>
                        <div class="main-slider-three__shape-one">
                            <img src="assets/images/shapes/slider-3-shape-1.png" alt="ienet">
                        </div>
                        <div class="main-slider-three__shape-two">
                            <img src="assets/images/resources/slider-3-shape-2.png" alt="ienet">
                        </div>
                        <div class="main-slider-three__content">
                            <h5 class="main-slider-three__sub-title">We make the web a better place!</h5>
                            <!-- slider-sub-title -->
                            <h2 class="main-slider-three__title">Best <span>Internet</span><br> Service Provider<br> In Your
                                Region</h2><!-- slider-title -->
                            <p class="main-slider-three__text">
                                Donec pretium ornare neque, ac luctus orci ultrices at. Sed blandit<br> eleifend mi, a
                                consectetur tortor varius in.
                                Sed tincidunt aliquet lorem,<br> eget tincidunt est molestie non. 
                            </p><!-- slider-tex -->
                            <div class="main-slider-three__btn">
                                <a href="services.html" class="ienet-btn main-slider-three__btn__first"><span>our service<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                                <!-- slider-btn -->
                                <a href="contact.html" class="ienet-btn main-slider-three__btn__last"><span><span class="ienet-btn__icon ienet-btn__icon--left"><i class="fas fa-gem"></i></span>Contact Now</span></a><!-- slider-btn -->
                            </div>
                        </div>
                        <div class="main-slider-three__image">
                            <div class="main-slider-three__layer-bg"></div>
                            <div class="main-slider-three__layer" style="background-image: url(assets/images/backgrounds/slider-3-layer-3.jpg);"></div>
                            <div class="main-slider-three__price">start form<br> <span>$39 /</span> month</div>
                            <div class="main-slider-three__layer-shape"></div>
                            <div class="main-slider-three__layer-shape-two">
                                <img src="assets/images/shapes/slider-3-shape-3.png" alt="ienet">
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <!-- main-slider-end -->

        <!-- Service Start -->
        <section class="service-one">
            <div class="container">
                <div class="row gutter-y-30">
                    <div class="col-xl-3 col-md-6 wow fadeInUp" data-wow-delay="00ms">
                        <div class="service-one__item text-center">
                            <div class="service-one__item__image">
                                <img src="assets/images/resources/service-1-1.jpg" alt="ienet">
                            </div>
                            <div class="service-one__item__shape">
                                <img src="assets/images/shapes/service-1-border.png" alt="ienet">
                            </div>
                            <h3 class="service-one__item__title">
                                <a href="service-d-broadband.html">Broadband Connect</a>
                            </h3><!-- /.service-title -->
                        </div><!-- /.service-card-one -->
                    </div>
                    <div class="col-xl-3 col-md-6 wow fadeInUp" data-wow-delay="50ms">
                        <div class="service-one__item service-one__item--reverse text-center">
                            <div class="service-one__item__image">
                                <img src="assets/images/resources/service-1-2.jpg" alt="ienet">
                            </div>
                            <div class="service-one__item__shape">
                                <img src="assets/images/shapes/service-1-border.png" alt="ienet">
                            </div>
                            <h3 class="service-one__item__title">
                                <a href="service-d-landline.html">Satellite Channel</a>
                            </h3><!-- /.service-title -->
                        </div><!-- /.service-card-one -->
                    </div>
                    <div class="col-xl-3 col-md-6 wow fadeInUp" data-wow-delay="100ms">
                        <div class="service-one__item text-center">
                            <div class="service-one__item__image">
                                <img src="assets/images/resources/service-1-3.jpg" alt="ienet">
                            </div>
                            <div class="service-one__item__shape">
                                <img src="assets/images/shapes/service-1-border.png" alt="ienet">
                            </div>
                            <h3 class="service-one__item__title">
                                <a href="service-d-iptv.html">IPTV Connection</a>
                            </h3><!-- /.service-title -->
                        </div><!-- /.service-card-one -->
                    </div>
                    <div class="col-xl-3 col-md-6 wow fadeInUp" data-wow-delay="150ms">
                        <div class="service-one__item service-one__item--reverse text-center">
                            <div class="service-one__item__image">
                                <img src="assets/images/resources/service-1-4.jpg" alt="ienet">
                            </div>
                            <div class="service-one__item__shape">
                                <img src="assets/images/shapes/service-1-border.png" alt="ienet">
                            </div>
                            <h3 class="service-one__item__title">
                                <a href="service-d-connectivity.html">Home IP Phone</a>
                            </h3><!-- /.service-title -->
                        </div><!-- /.service-card-one -->
                    </div>
                </div>
            </div>
        </section>
        <!-- Service End -->

        <section class="about-three">
            <div class="about-three__bg-wrapper">
                <div class="about-three__bg" style="background-image: url(assets/images/shapes/about-3-bg.png);"></div>
            </div>
            <div class="container">
                <div class="row">
                    <div class="col-lg-6">
                        <div class="about-three__image wow fadeInLeft" data-wow-delay="100ms">
                            <div class="about-three__image__one">
                                <img src="assets/images/resources/about-3-1.jpg" alt="ienet">
                            </div>
                            <div class="about-three__image__two wow fadeInUp" data-wow-delay="200ms">
                                <img src="assets/images/resources/about-3-2.png" alt="ienet">
                            </div>
                            <div class="about-three__image__experiance wow fadeInUp" data-wow-delay="300ms">
                                <div class="about-three__image__experiance__shape" style="background-image: url(assets/images/shapes/about-3-experiance.png);"></div>
                                <div class="about-three__image__experiance__icon"><i class=" icon-medal"></i></div>
                                <h5 class="about-three__image__experiance__number count-box"><span class="count-text" data-stop="25" data-speed="1500"></span>Years</h5>
                                <p class="about-three__image__experiance__text">Working Experience</p>
                            </div>
                        </div><!-- /.about-three__image -->
                    </div><!-- /.col-lg-6 -->
                    <div class="col-lg-6 wow fadeInRight" data-wow-delay="00ms">
                        <div class="about-three__content">
                            <div class="sec-title text-left">

                                <h6 class="sec-title__tagline bw-split-in-right"><span class="sec-title__tagline__left-border"></span>About Our Internet<span class="sec-title__tagline__right-border"></span></h6><!-- /.sec-title__tagline -->

                                <h3 class="sec-title__title bw-split-in-left">Best <span>Internet</span> Provide Agency In Town</h3><!-- /.sec-title__title -->
                            </div><!-- /.sec-title -->
                            <p class="about-three__content__text">
                                It is a long established fact that a reader will be distracted the readable content of a page
                                when looking
                                at layout the point of using lorem the is Ipsum less normal distribution of letters.
                            </p>
                            <div class="row gutter-y-30">
                                <div class="col-md-5">
                                    <div class="about-three__box">
                                        <div class="about-three__box__icon"><i class="icon-world"></i></div>
                                        <h5 class="about-three__box__title">Fast Connected</h5>
                                        <p class="about-three__box__text">
                                            Embarrassing hidden in the middle All the Lorem
                                        </p>
                                    </div>
                                </div>
                                <div class="col-md-7">
                                    <div class="about-three__video" style="background-image: url(assets/images/resources/about-3-video.jpg);">
                                        <a href="https://www.youtube.com/watch?v=h9MbznbxlLc" class="video-popup">
                                            <i class="fa fa-play"></i>
                                            <i class="ripple"></i>
                                        </a>
                                    </div>
                                </div>
                            </div>
                            <div class="about-three__info">
                                <a href="about.html" class="ienet-btn"><span>More About Us<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                                <div class="about-three__info__call">
                                    <div class="about-three__info__call__icon"><span class="icon-telephone"></span></div>
                                    <div class="about-three__info__call__title">Call Emergency</div>
                                    <a class="about-three__info__call__text" href="tel:88012365499">+88 0123 654 99</a>
                                </div>
                            </div>
                        </div><!-- /.about-three__content -->
                    </div><!-- /.col-lg-6 -->
                </div><!-- /.row -->
            </div><!-- /.container -->
        </section><!-- /.about-three -->

        <section class="packages-three">
            <div class="packages-three__shape-left" style="background-image: url(assets/images/shapes/packages-3-shape-left.png);"></div>
            <div class="packages-three__shape-right" style="background-image: url(assets/images/shapes/packages-3-shape-right.png);"></div>
            <div class="container">
                <div class="row">
                    <div class="col-md-8 wow fadeInUp" data-wow-delay="00ms">
                        <div class="sec-title text-left">

                            <h6 class="sec-title__tagline bw-split-in-right"><span class="sec-title__tagline__left-border"></span>Our Best Plan<span class="sec-title__tagline__right-border"></span></h6><!-- /.sec-title__tagline -->

                            <h3 class="sec-title__title bw-split-in-left">Select Your <span>Best Plan</span></h3><!-- /.sec-title__title -->
                        </div><!-- /.sec-title -->
                    </div>
                    <div class="col-md-4 wow fadeInUp" data-wow-delay="00ms">
                        <a href="packages.html" class="ienet-btn packages-three__btn"><span>View All Service<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                    </div>
                </div>
                <div class="packages-three__card wow fadeInUp" data-wow-delay="00ms">
                    <div class="packages-three__card__image">
                        <img src="assets/images/resources/package-3-1.jpg" alt="ienet">
                        <h3 class="packages-three__card__title">TV + Internet package</h3>
                    </div>
                    <ul class="packages-three__card__list">
                        <li><span class="fas fa-check"></span>Internet with a 100Mbps</li>
                        <li><span class="fas fa-check"></span>Connect multiple users</li>
                        <li><span class="fas fa-check"></span>WiFi router & prevention</li>
                        <li><span class="fas fa-check"></span>Unlimited devices</li>
                    </ul>
                    <div class="packages-three__card__price">$39 <span>Month</span></div>
                    <div class="packages-three__card__rm">
                        <a href="contact.html" class="ienet-btn"><span>Choose Plan<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                    </div>
                </div><!-- item -->
                <div class="packages-three__card wow fadeInUp" data-wow-delay="50ms">
                    <div class="packages-three__card__image">
                        <img src="assets/images/resources/package-3-2.jpg" alt="ienet">
                        <h3 class="packages-three__card__title">Home Basic Package</h3>
                    </div>
                    <ul class="packages-three__card__list">
                        <li><span class="fas fa-check"></span>Internet with a 100Mbps</li>
                        <li><span class="fas fa-check"></span>Connect multiple users</li>
                        <li><span class="fas fa-check"></span>WiFi router & prevention</li>
                        <li><span class="fas fa-check"></span>Unlimited devices</li>
                    </ul>
                    <div class="packages-three__card__price">$49 <span>Month</span></div>
                    <div class="packages-three__card__rm">
                        <a href="contact.html" class="ienet-btn"><span>Choose Plan<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                    </div>
                </div><!-- item -->
                <div class="packages-three__card wow fadeInUp" data-wow-delay="100ms">
                    <div class="packages-three__card__image">
                        <img src="assets/images/resources/package-3-3.jpg" alt="ienet">
                        <h3 class="packages-three__card__title">Corporate package</h3>
                    </div>
                    <ul class="packages-three__card__list">
                        <li><span class="fas fa-check"></span>Internet with a 100Mbps</li>
                        <li><span class="fas fa-check"></span>Connect multiple users</li>
                        <li><span class="fas fa-check"></span>WiFi router & prevention</li>
                        <li><span class="fas fa-check"></span>Unlimited devices</li>
                    </ul>
                    <div class="packages-three__card__price">$59 <span>Month</span></div>
                    <div class="packages-three__card__rm">
                        <a href="contact.html" class="ienet-btn"><span>Choose Plan<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                    </div>
                </div><!-- item -->
                <div class="packages-three__card wow fadeInUp" data-wow-delay="150ms">
                    <div class="packages-three__card__image">
                        <img src="assets/images/resources/package-3-4.jpg" alt="ienet">
                        <h3 class="packages-three__card__title">Premium fast package</h3>
                    </div>
                    <ul class="packages-three__card__list">
                        <li><span class="fas fa-check"></span>Internet with a 100Mbps</li>
                        <li><span class="fas fa-check"></span>Connect multiple users</li>
                        <li><span class="fas fa-check"></span>WiFi router & prevention</li>
                        <li><span class="fas fa-check"></span>Unlimited devices</li>
                    </ul>
                    <div class="packages-three__card__price">$79 <span>Month</span></div>
                    <div class="packages-three__card__rm">
                        <a href="contact.html" class="ienet-btn"><span>Choose Plan<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                    </div>
                </div><!-- item -->
            </div>
        </section>

        <!-- Feature Start -->
        <section class="feature-three">
            <div class="feature-three__bg jarallax" data-jarallax data-speed="0.3" data-imgPosition="50% -100%" style="background-image: url(assets/images/backgrounds/feature-bg-3.jpg);"></div>
            <div class="container">
                <div class="sec-title text-center">

                    <h6 class="sec-title__tagline bw-split-in-right"><span class="sec-title__tagline__left-border"></span>Our facility<span class="sec-title__tagline__right-border"></span></h6><!-- /.sec-title__tagline -->

                    <h3 class="sec-title__title bw-split-in-left">Our Special <span>Features</span></h3><!-- /.sec-title__title -->
                </div><!-- /.sec-title -->
                <div class="row">
                    <div class="col-xl-4 col-lg-5 wow fadeInLeft" data-wow-delay="00ms">
                        <div class="feature-three__box">
                            <div class="feature-three__box__icon"><i class="icon-dashboard"></i></div>
                            <h5 class="feature-three__box__title">Ultra-Speed Connection</h5>
                            <p class="feature-three__box__text">
                                Nulla facilisi. Pellentesque imperdiet,<br> sem et commodo interdum, justo velit.
                            </p>
                        </div>
                        <div class="feature-three__box">
                            <div class="feature-three__box__icon"><i class="icon-tv"></i></div>
                            <h5 class="feature-three__box__title">250+ TV chanels</h5>
                            <p class="feature-three__box__text">
                                Nulla facilisi. Pellentesque imperdiet,<br> sem et commodo interdum, justo velit.
                            </p>
                        </div>
                        <div class="feature-three__box">
                            <div class="feature-three__box__icon"><i class="icon-planning"></i></div>
                            <h5 class="feature-three__box__title">Flexible Plans</h5>
                            <p class="feature-three__box__text">
                                Nulla facilisi. Pellentesque imperdiet,<br> sem et commodo interdum, justo velit.
                            </p>
                        </div>
                    </div>
                    <div class="col-xl-8 col-lg-7 wow fadeInUp" data-wow-delay="100ms">
                        <div class="feature-three__image">
                            <div class="feature-three__image__one">
                                <img src="assets/images/resources/feature-3-1.jpg" alt="ienet">
                            </div>
                            <div class="feature-three__image__border">
                                <img src="assets/images/shapes/feature-3-border.png" alt="ienet">
                            </div>
                            <div class="feature-three__image__two">
                                <img src="assets/images/resources/feature-3-2.jpg" alt="ienet">
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <!-- Feature End -->

        <section class="cta-three">
            <div class="cta-three__shape-one" style="background-image: url(assets/images/shapes/cta-3-shape-1.png);"></div>
            <div class="cta-three__shape-two" style="background-image: url(assets/images/shapes/cta-3-shape-2.png);"></div>
            <div class="container">
                <div class="row">
                    <div class="col-xl-6">
                        <div class="ienet-stretch-element-inside-column">
                            <div class="cta-three__image">
                                <div class="cta-three__image__one wow fadeInLeft" data-wow-delay="00ms">
                                    <img src="assets/images/resources/cta-three-3-1.jpg" alt="ienet">
                                </div>
                                <div class="cta-three__image__border wow fadeInLeft" data-wow-delay="00ms">
                                    <img src="assets/images/shapes/cta-3-border.png" alt="ienet">
                                </div>
                                <div class="cta-three__image__two wow fadeInUp" data-wow-delay="100ms">
                                    <img src="assets/images/resources/cta-three-3-2.jpg" alt="ienet">
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-xl-6 wow fadeInRight" data-wow-delay="100ms">
                        <div class="cta-three__content tabs-box">
                            <div class="sec-title text-left">

                                <h6 class="sec-title__tagline bw-split-in-right"><span class="sec-title__tagline__left-border"></span>save your money<span class="sec-title__tagline__right-border"></span></h6><!-- /.sec-title__tagline -->

                                <h3 class="sec-title__title bw-split-in-left">Find The Best <span>Internet</span> Service With Speed You Need</h3><!-- /.sec-title__title -->
                            </div><!-- /.sec-title -->
                            <ul class="cta-three__content__tab tab-buttons list-unstyled">
                                <li data-tab="#20mbps" class="tab-btn">20 MBPS</li>
                                <li data-tab="#30mbps" class="tab-btn active-btn">30 MBPS</li>
                                <li data-tab="#50mbps" class="tab-btn">50 MBPS</li>
                            </ul>
                            <div class="tabs-content">
                                <div class="tab fadeInUp animated" id="20mbps">
                                    <p class="cta-three__content__text">
                                        Donec pretium ornare neque, ac luctus orci ultrices at. Sed blandit eleifend mi, a
                                        consectetur tortor varius in.
                                        Sed tincidunt aliquet lorem, eget tincidunt
                                    </p>
                                    <ul class="cta-three__content__list">
                                        <li><span class="fas fa-check"></span>Super-Fast Dongle</li>
                                        <li><span class="fas fa-check"></span>High Speed Wi-Fi</li>
                                        <li><span class="fas fa-check"></span>Prepaid SIM</li>
                                        <li><span class="fas fa-check"></span>5G Updations</li>
                                    </ul>
                                    <a href="about.html" class="ienet-btn"><span>Get In Touch<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                                </div><!-- 20mbs -->
                                <div class="tab fadeInUp animated active-tab" id="30mbps">
                                    <p class="cta-three__content__text">
                                        Donec pretium ornare neque, ac luctus orci ultrices at. Sed blandit eleifend mi, a
                                        consectetur tortor varius in.
                                        Sed tincidunt aliquet lorem, eget tincidunt
                                    </p>
                                    <ul class="cta-three__content__list">
                                        <li><span class="fas fa-check"></span>Super-Fast Dongle</li>
                                        <li><span class="fas fa-check"></span>High Speed Wi-Fi</li>
                                        <li><span class="fas fa-check"></span>Prepaid SIM</li>
                                        <li><span class="fas fa-check"></span>5G Updations</li>
                                    </ul>
                                    <a href="about.html" class="ienet-btn"><span>Get In Touch<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                                </div><!-- 30mbs -->
                                <div class="tab fadeInUp animated" id="50mbps">
                                    <p class="cta-three__content__text">
                                        Donec pretium ornare neque, ac luctus orci ultrices at. Sed blandit eleifend mi, a
                                        consectetur tortor varius in.
                                        Sed tincidunt aliquet lorem, eget tincidunt
                                    </p>
                                    <ul class="cta-three__content__list">
                                        <li><span class="fas fa-check"></span>Super-Fast Dongle</li>
                                        <li><span class="fas fa-check"></span>High Speed Wi-Fi</li>
                                        <li><span class="fas fa-check"></span>Prepaid SIM</li>
                                        <li><span class="fas fa-check"></span>5G Updations</li>
                                    </ul>
                                    <a href="about.html" class="ienet-btn"><span>Get In Touch<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                                </div><!-- 50mbs -->
                            </div>
                        </div>
                    </div>
                </div>
            </div><!-- /.container -->
        </section><!-- /.cta-three -->

        <section class="faq-one faq-one--home-three">
            <div class="faq-one__bg" style="background-image: url(assets/images/shapes/faq-bg-3.png);"></div>
            <div class="container">
                <div class="row">
                    <div class="col-lg-6">
                        <div class="faq-one__content">
                            <div class="sec-title text-left">

                                <h6 class="sec-title__tagline bw-split-in-right"><span class="sec-title__tagline__left-border"></span>frequently asked questions<span class="sec-title__tagline__right-border"></span></h6><!-- /.sec-title__tagline -->

                                <h3 class="sec-title__title bw-split-in-left">Why Should <span>Work</span> With Us</h3><!-- /.sec-title__title -->
                            </div><!-- /.sec-title -->
                            <!-- section-title -->
                            <div class="about-two__content__box">
                                <div class="about-two__content__box__icon"><i class="icon-world"></i></div>
                                <h5 class="about-two__content__box__title">Fast Connected</h5>
                                <p class="about-two__content__box__text">
                                    Embarrassing hidden in the middle All the Lorem Ipsum<br> generators on the Internet repeat
                                    predefined chunks
                                </p>
                            </div>
                            <div class="about-two__content__box">
                                <div class="about-two__content__box__icon"><i class="icon-wifi-router"></i></div>
                                <h5 class="about-two__content__box__title">Free Installations</h5>
                                <p class="about-two__content__box__text">
                                    Embarrassing hidden in the middle All the Lorem Ipsum<br> generators on the Internet repeat
                                    predefined chunks
                                </p>
                            </div>
                        </div><!-- /.faq-one__contact -->
                    </div><!-- /.col-lg-6 -->
                    <div class="col-lg-6">
                        <div class="faq-one__accordion ienet-accrodion" data-grp-name="ienet-accrodion">
                            <div class="accrodion">
                                <div class="accrodion-title">
                                    <h4>
                                        <span class="accrodion-title__icon"></span><!-- /.accrodion-title__icon -->
                                        What is broadband internet?
                                    </h4>
                                </div><!-- /.accordian-title -->
                                <div class="accrodion-content">
                                    <div class="inner">
                                        <p>
                                            Bring to the table win-win survival strategies to ensure proactive domination. At
                                            the end of the day, going forward,
                                            a new normal that has evolved from generation X is on the
                                        </p>
                                    </div><!-- /.accordian-content -->
                                </div>
                            </div><!-- /.accordian-item -->
                            <div class="accrodion active">
                                <div class="accrodion-title">
                                    <h4>
                                        <span class="accrodion-title__icon"></span><!-- /.accrodion-title__icon -->
                                        How does broadband internet work?
                                    </h4>
                                </div><!-- /.accordian-title -->
                                <div class="accrodion-content">
                                    <div class="inner">
                                        <p>
                                            Bring to the table win-win survival strategies to ensure proactive domination. At
                                            the end of the day, going forward,
                                            a new normal that has evolved from generation X is on the
                                        </p>
                                    </div><!-- /.accordian-content -->
                                </div>
                            </div><!-- /.accordian-item -->
                            <div class="accrodion">
                                <div class="accrodion-title">
                                    <h4>
                                        <span class="accrodion-title__icon"></span><!-- /.accrodion-title__icon -->
                                        What is the difference between upload and download speeds?
                                    </h4>
                                </div><!-- /.accordian-title -->
                                <div class="accrodion-content">
                                    <div class="inner">
                                        <p>
                                            Bring to the table win-win survival strategies to ensure proactive domination. At
                                            the end of the day, going forward,
                                            a new normal that has evolved from generation X is on the
                                        </p>
                                    </div><!-- /.accordian-content -->
                                </div>
                            </div><!-- /.accordian-item -->
                            <div class="accrodion">
                                <div class="accrodion-title">
                                    <h4>
                                        <span class="accrodion-title__icon"></span><!-- /.accrodion-title__icon -->
                                        What factors can affect broadband speed?
                                    </h4>
                                </div><!-- /.accordian-title -->
                                <div class="accrodion-content">
                                    <div class="inner">
                                        <p>
                                            Bring to the table win-win survival strategies to ensure proactive domination. At
                                            the end of the day, going forward,
                                            a new normal that has evolved from generation X is on the
                                        </p>
                                    </div><!-- /.accordian-content -->
                                </div>
                            </div><!-- /.accordian-item -->
                        </div>
                    </div><!-- /.col-lg-6 -->
                </div><!-- /.row -->
            </div><!-- /.container -->
        </section><!-- /.faq-one -->

        <div class="section-divider"></div>
        <section class="movie-two">
            <div class="movie-two__bg-wrapper">
                <div class="movie-two__bg jarallax" data-jarallax data-speed="0.3" data-imgPosition="50% -100%" style="background-image: url(assets/images/backgrounds/movie-bg-2.jpg);"></div>
                <div class="movie-two__shape" style="background-image: url(assets/images/movie/movie-shape-2.png);"></div>
            </div><!-- /.movie-two__bg -->
            <div class="container">
                <div class="sec-title text-center">

                    <h6 class="sec-title__tagline bw-split-in-right"><span class="sec-title__tagline__left-border"></span>entertainment<span class="sec-title__tagline__right-border"></span></h6><!-- /.sec-title__tagline -->

                    <h3 class="sec-title__title bw-split-in-left">Popular <span>Featured</span> Show</h3><!-- /.sec-title__title -->
                </div><!-- /.sec-title -->
                <div class="row">
                    <div class="col-xl-3 col-md-6">
                        <div class="movie-two__item">
                            <div class="movie-two__item__image">
                                <img src="assets/images/movie/movie-2-1.jpg" alt="ienet">
                            </div>
                            <a href="https://www.youtube.com/watch?v=h9MbznbxlLc" class="video-popup">
                                <i class="fa fa-play"></i>
                                <i class="ripple"></i>
                            </a>
                            <div class="movie-two__item__content">
                                <h3 class="movie-two__item__title"><a href="movie-details.html">The Dark Knight</a></h3>
                                <ul class="movie-two__item__list">
                                    <li><i class="fa fa-star"></i>6.8(Imdb)</li>
                                    <li>1hr : 30mins</li>
                                </ul>
                            </div>
                        </div>
                        <!--item-->
                        <div class="movie-two__item">
                            <div class="movie-two__item__image">
                                <img src="assets/images/movie/movie-2-2.jpg" alt="ienet">
                            </div>
                            <a href="https://www.youtube.com/watch?v=h9MbznbxlLc" class="video-popup">
                                <i class="fa fa-play"></i>
                                <i class="ripple"></i>
                            </a>
                            <div class="movie-two__item__content">
                                <h3 class="movie-two__item__title"><a href="movie-details.html">Prem Ratan Dhan</a></h3>
                                <ul class="movie-two__item__list">
                                    <li><i class="fa fa-star"></i>6.8(Imdb)</li>
                                    <li>1hr : 30mins</li>
                                </ul>
                            </div>
                        </div>
                        <!--item-->
                        <div class="movie-two__item">
                            <div class="movie-two__item__image">
                                <img src="assets/images/movie/movie-2-3.jpg" alt="ienet">
                            </div>
                            <a href="https://www.youtube.com/watch?v=h9MbznbxlLc" class="video-popup">
                                <i class="fa fa-play"></i>
                                <i class="ripple"></i>
                            </a>
                            <div class="movie-two__item__content">
                                <h3 class="movie-two__item__title"><a href="movie-details.html">The Jungle Book</a></h3>
                                <ul class="movie-two__item__list">
                                    <li><i class="fa fa-star"></i>6.8(Imdb)</li>
                                    <li>1hr : 30mins</li>
                                </ul>
                            </div>
                        </div>
                        <!--item-->
                    </div>
                    <div class="col-xl-6 col-md-6 movie-two__col">
                        <div class="movie-two__featured">
                            <div class="movie-two__featured__image">
                                <img src="assets/images/movie/movie-featured.jpg" alt="ienet">
                            </div><!-- /.movie-two__featured__image -->
                            <a href="https://www.youtube.com/watch?v=h9MbznbxlLc" class="video-popup">
                                <i class="fa fa-play"></i>
                                <i class="ripple"></i>
                            </a>
                            <div class="movie-two__featured__content">
                                <h3 class="movie-two__featured__title"><a href="movie-details.html">The Dark Knight</a></h3>
                                <ul class="movie-two__featured__list">
                                    <li><i class="fa fa-star"></i>6.8(Imdb)</li>
                                    <li>1hr : 30mins</li>
                                </ul>
                            </div>
                        </div>
                    </div>
                    <div class="col-xl-3 col-md-6">
                        <div class="movie-two__item">
                            <div class="movie-two__item__image">
                                <img src="assets/images/movie/movie-2-4.jpg" alt="ienet">
                            </div>
                            <a href="https://www.youtube.com/watch?v=h9MbznbxlLc" class="video-popup">
                                <i class="fa fa-play"></i>
                                <i class="ripple"></i>
                            </a>
                            <div class="movie-two__item__content">
                                <h3 class="movie-two__item__title"><a href="movie-details.html">The Dark Knight</a></h3>
                                <ul class="movie-two__item__list">
                                    <li><i class="fa fa-star"></i>6.8(Imdb)</li>
                                    <li>1hr : 30mins</li>
                                </ul>
                            </div>
                        </div>
                        <!--item-->
                        <div class="movie-two__item">
                            <div class="movie-two__item__image">
                                <img src="assets/images/movie/movie-2-5.jpg" alt="ienet">
                            </div>
                            <a href="https://www.youtube.com/watch?v=h9MbznbxlLc" class="video-popup">
                                <i class="fa fa-play"></i>
                                <i class="ripple"></i>
                            </a>
                            <div class="movie-two__item__content">
                                <h3 class="movie-two__item__title"><a href="movie-details.html">Prem Ratan Dhan</a></h3>
                                <ul class="movie-two__item__list">
                                    <li><i class="fa fa-star"></i>6.8(Imdb)</li>
                                    <li>1hr : 30mins</li>
                                </ul>
                            </div>
                        </div>
                        <!--item-->
                        <div class="movie-two__item">
                            <div class="movie-two__item__image">
                                <img src="assets/images/movie/movie-2-6.jpg" alt="ienet">
                            </div>
                            <a href="https://www.youtube.com/watch?v=h9MbznbxlLc" class="video-popup">
                                <i class="fa fa-play"></i>
                                <i class="ripple"></i>
                            </a>
                            <div class="movie-two__item__content">
                                <h3 class="movie-two__item__title"><a href="movie-details.html">The Jungle Book</a></h3>
                                <ul class="movie-two__item__list">
                                    <li><i class="fa fa-star"></i>6.8(Imdb)</li>
                                    <li>1hr : 30mins</li>
                                </ul>
                            </div>
                        </div>
                        <!--item-->
                    </div>
                </div>
            </div>
        </section>

        <section class="testimonials-three">
            <div class="container">
                <div class="sec-title text-left">

                    <h6 class="sec-title__tagline bw-split-in-right"><span class="sec-title__tagline__left-border"></span>our testimonials<span class="sec-title__tagline__right-border"></span></h6><!-- /.sec-title__tagline -->

                    <h3 class="sec-title__title bw-split-in-left">What Peoples <span>Talked</span><br> About Us</h3><!-- /.sec-title__title -->
                </div><!-- /.sec-title -->
                <div class="testimonials-three__wrapper">
                    <!-- Testimonial Thumb -->
                    <ul class="testimonials-three__carousel-thumb ienet-slick__carousel" data-slick-options='{
				"slidesToShow": 4,
				"slidesToScroll": 1,
				"autoplay": true,
				"centerMode": true,
				"asNavFor": ".testimonials-three__carousel",
				"focusOnSelect": true,
				"dots": false,
				"centerPadding": 0,
				"arrows": false
				}'>
                        <li role="presentation">
                            <span class="testimonials-three__meta-thumb"><img src="assets/images/resources/testi-3-1.jpg" alt="ienet"></span>
                        </li><!-- Testimonial Item -->
                        <li role="presentation">
                            <span class="testimonials-three__meta-thumb"><img src="assets/images/resources/testi-3-2.jpg" alt="ienet"></span>
                        </li><!-- Testimonial Item -->
                        <li role="presentation">
                            <span class="testimonials-three__meta-thumb"><img src="assets/images/resources/testi-3-3.jpg" alt="ienet"></span>
                        </li><!-- Testimonial Item -->
                        <li role="presentation">
                            <span class="testimonials-three__meta-thumb"><img src="assets/images/resources/testi-3-4.jpg" alt="ienet"></span>
                        </li><!-- Testimonial Item -->
                        <li role="presentation">
                            <span class="testimonials-three__meta-thumb"><img src="assets/images/resources/testi-3-5.jpg" alt="ienet"></span>
                        </li><!-- Testimonial Item -->
                    </ul>
                    <!-- Testimonial Thumb -->
                    <div class="testimonials-three__carousel ienet-slick__carousel" data-slick-options='{
				"slidesToShow": 1,
				"slidesToScroll": 1,
				"asNavFor": ".testimonials-three__carousel-thumb",
				"autoplay": true,
				"dots": true,
				"centerPadding": 0,
				"arrows": false
				}'>
                        <div class="item">
                            <div class="testimonials-three__item">
                                <div class="testimonials-three__quote" style="background-image: url(assets/images/shapes/testimonial-3-quote.png);"></div>
                                <h3 class="testimonials-three__name">
                                    Anthony B. Castillo
                                </h3><!-- /.testimonials-three__name -->
                                <p class="testimonials-three__designation">managing director</p>
                                <!-- /.testimonials-three__designation -->
                                <div class="testimonials-three__content">
                                    Overall, I highly recommend XYZ Broadband agency to anyone in need of Internet service.
                                    Their combination of high-quality products and outstandi customer service makes them
                                    stand out in the industry. I will definitely be areturning customer in the future.
                                </div><!-- /.testimonials-three__content -->
                                <div class="testimonials-three__rating">
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                </div><!-- /.testimonials-card__rating -->
                            </div>
                        </div><!-- /.item -->
                        <div class="item">
                            <div class="testimonials-three__item">
                                <div class="testimonials-three__quote" style="background-image: url(assets/images/shapes/testimonial-3-quote.png);"></div>
                                <h3 class="testimonials-three__name">
                                    Sarah Albert
                                </h3><!-- /.testimonials-three__name -->
                                <p class="testimonials-three__designation">Founder</p><!-- /.testimonials-three__designation -->
                                <div class="testimonials-three__content">
                                    Overall, I highly recommend XYZ Broadband agency to anyone in need of Internet service.
                                    Their combination of high-quality products and outstandi customer service makes them
                                    stand out in the industry. I will definitely be areturning customer in the future.
                                </div><!-- /.testimonials-three__content -->
                                <div class="testimonials-three__rating">
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                </div><!-- /.testimonials-card__rating -->
                            </div>
                        </div><!-- /.item -->
                        <div class="item">
                            <div class="testimonials-three__item">
                                <div class="testimonials-three__quote" style="background-image: url(assets/images/shapes/testimonial-3-quote.png);"></div>
                                <h3 class="testimonials-three__name">
                                    David Cooper
                                </h3><!-- /.testimonials-three__name -->
                                <p class="testimonials-three__designation">Co Founder</p>
                                <!-- /.testimonials-three__designation -->
                                <div class="testimonials-three__content">
                                    Overall, I highly recommend XYZ Broadband agency to anyone in need of Internet service.
                                    Their combination of high-quality products and outstandi customer service makes them
                                    stand out in the industry. I will definitely be areturning customer in the future.
                                </div><!-- /.testimonials-three__content -->
                                <div class="testimonials-three__rating">
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                </div><!-- /.testimonials-card__rating -->
                            </div>
                        </div><!-- /.item -->
                        <div class="item">
                            <div class="testimonials-three__item">
                                <div class="testimonials-three__quote" style="background-image: url(assets/images/shapes/testimonial-3-quote.png);"></div>
                                <h3 class="testimonials-three__name">
                                    Mark Smith
                                </h3><!-- /.testimonials-three__name -->
                                <p class="testimonials-three__designation">Reviwer</p><!-- /.testimonials-three__designation -->
                                <div class="testimonials-three__content">
                                    Overall, I highly recommend XYZ Broadband agency to anyone in need of Internet service.
                                    Their combination of high-quality products and outstandi customer service makes them
                                    stand out in the industry. I will definitely be areturning customer in the future.
                                </div><!-- /.testimonials-three__content -->
                                <div class="testimonials-three__rating">
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                </div><!-- /.testimonials-card__rating -->
                            </div>
                        </div><!-- /.item -->
                        <div class="item">
                            <div class="testimonials-three__item">
                                <div class="testimonials-three__quote" style="background-image: url(assets/images/shapes/testimonial-3-quote.png);"></div>
                                <h3 class="testimonials-three__name">
                                    Joh Doe
                                </h3><!-- /.testimonials-three__name -->
                                <p class="testimonials-three__designation">Customer</p>
                                <!-- /.testimonials-three__designation -->
                                <div class="testimonials-three__content">
                                    Overall, I highly recommend XYZ Broadband agency to anyone in need of Internet service.
                                    Their combination of high-quality products and outstandi customer service makes them
                                    stand out in the industry. I will definitely be areturning customer in the future.
                                </div><!-- /.testimonials-three__content -->
                                <div class="testimonials-three__rating">
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                    <i class="fa fa-star"></i>
                                </div><!-- /.testimonials-card__rating -->
                            </div>
                        </div><!-- /.item -->
                    </div><!-- /.testimonials-three__carousel -->
                </div>
            </div><!-- /.container -->
        </section><!-- /.testimonials-three -->

        <section class="blog-three">
            <div class="blog-three__bg" style="background-image: url(assets/images/shapes/blog-bg-3.png);"></div>
            <div class="container">
                <div class="sec-title text-center">

                    <h6 class="sec-title__tagline bw-split-in-right"><span class="sec-title__tagline__left-border"></span>latest blog<span class="sec-title__tagline__right-border"></span></h6><!-- /.sec-title__tagline -->

                    <h3 class="sec-title__title bw-split-in-left">Our Latest <span>Blog</span> News</h3><!-- /.sec-title__title -->
                </div><!-- /.sec-title -->
                <div class="row">
                    <div class="col-lg-9">
                        <div class="blog-three__item">
                            <div class="blog-three__item__image">
                                <img src="assets/images/blog/blog-2-1.png" alt="ienet">
                                <img src="assets/images/blog/blog-2-1.png" alt="ienet">
                                <a href="blog-details-right.html" class="blog-three__item__image__link"><span class="sr-only">ienet</span><!-- /.sr-only --></a>
                            </div>
                            <!--blog-image-->
                            <div class="blog-three__item__content">
                                <div class="blog-three__item__content__item">
                                    <div class="blog-three__item__date">AUG, 04</div><!-- /.blog-card__date -->
                                    <ul class="list-unstyled blog-three__item__meta">
                                        <li><a href="blog-list-right.html"><i class="fas fa-user-alt"></i>by Admin</a></li>
                                        <li><a href="blog-details-right.html"><i class="fas fa-comment-dots"></i>2 Comments</a>
                                        </li>
                                    </ul><!-- /.list-unstyled blog-card__meta -->
                                    <h3 class="blog-three__item__title"><a href="blog-details-right.html">Cupidatat Nonproident,
                                            Sunt in Culpa qui Officia Deserunt</a></h3><!-- /.blog-card__title -->
                                    <p class="blog-three__item__text">
                                        Donec pretium ornare neque, ac luctus orci ultrices at. Sed blandit eifend mi, a
                                        consectetur tortor varius in. Sed tincidunt aliquet lorem, eget
                                    </p><!-- /.blog-card__text -->
                                </div>
                                <div class="blog-three__item__content__item">
                                    <div class="blog-three__item__date">AUG, 04</div><!-- /.blog-card__date -->
                                    <ul class="list-unstyled blog-three__item__meta">
                                        <li><a href="blog-list-right.html"><i class="fas fa-user-alt"></i>by Admin</a></li>
                                        <li><a href="blog-details-right.html"><i class="fas fa-comment-dots"></i>2 Comments</a>
                                        </li>
                                    </ul><!-- /.list-unstyled blog-card__meta -->
                                    <h3 class="blog-three__item__title"><a href="blog-details-right.html">There are Several
                                            Types of Connections Available</a></h3><!-- /.blog-card__title -->
                                    <p class="blog-three__item__text">
                                        Donec pretium ornare neque, ac luctus orci ultrices at. Sed blandit eifend mi, a
                                        consectetur tortor varius in. Sed tincidunt aliquet lorem, eget
                                    </p><!-- /.blog-card__text -->
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-3">
                        <div class="blog-card wow fadeInUp" data-wow-duration='1500ms' data-wow-delay='00ms'>
                            <div class="blog-card__image">
                                <img src="assets/images/blog/blog-1-4.png" alt="Cupidatat Nonproident, Sunt in Culpa qui Officia Deserunt">
                                <img src="assets/images/blog/blog-1-4.png" alt="Cupidatat Nonproident, Sunt in Culpa qui Officia Deserunt">
                                <a href="blog-details-right.html" class="blog-card__image__link"><span class="sr-only">Cupidatat Nonproident, Sunt in Culpa qui Officia Deserunt</span>
                                    <!-- /.sr-only --></a>
                                <div class="blog-card__date">AUG, 04</div><!-- /.blog-card__date -->
                                <ul class="list-unstyled blog-card__meta">
                                    <li><a href="blog-list-right.html"><i class="fas fa-user-alt"></i>by Admin</a></li>
                                    <li><a href="blog-details-right.html"><i class="fas fa-comment-dots"></i>2 Comments</a></li>
                                </ul><!-- /.list-unstyled blog-card__meta -->
                            </div><!-- /.blog-card__image -->
                            <div class="blog-card__content">
                                <h3 class="blog-card__title"><a href="blog-details-right.html">Cupidatat Nonproident, Sunt in Culpa qui Officia Deserunt</a></h3><!-- /.blog-card__title -->
                                <a href="blog-details-right.html" class="blog-card__link">
                                    <span class="blog-card__link__front"><span class="fas fa-angle-double-right"></span></span>
                                    <span class="blog-card__link__back"><span class="fas fa-angle-double-right"></span>Read More</span>
                                </a><!-- /.blog-card__link -->
                            </div><!-- /.blog-card__content -->
                        </div><!-- /.blog-card -->
                    </div>
                </div>
            </div><!-- /.container -->
        </section><!-- /.blog-one -->

        <div class="client-carousel ">
            <div class="container">
                <div class="client-carousel__one ienet-owl__carousel owl-theme owl-carousel" data-owl-options='{
            "items": 5,
            "margin": 65,
            "smartSpeed": 700,
            "loop":true,
            "autoplay": 6000,
            "nav":false,
            "dots":false,
            "navText": ["<span class=\"fa fa-angle-left\"></span>","<span class=\"fa fa-angle-right\"></span>"],
            "responsive":{
                "0":{
                    "items":1,
                    "margin": 0
                },
                "360":{
                    "items":2,
                    "margin": 30
                },
                "575":{
                    "items":3,
                    "margin": 30
                },
                "768":{
                    "items":3,
                    "margin": 40
                },
                "992":{
                    "items": 4,
                    "margin": 40
                },
                "1200":{
                    "items": 5,
                    "margin": 140
                }
            }
            }'>
                    <div class="client-carousel__one__item">
                        <img class="client-carousel__one__item__normal" src="assets/images/resources/brand-1-1.png" alt="ienet">
                        <img class="client-carousel__one__item__hover" src="assets/images/resources/brand-1-1-hover.png" alt="ienet">
                    </div><!-- /.owl-slide-item-->
                    <div class="client-carousel__one__item">
                        <img class="client-carousel__one__item__normal" src="assets/images/resources/brand-1-2.png" alt="ienet">
                        <img class="client-carousel__one__item__hover" src="assets/images/resources/brand-1-2-hover.png" alt="ienet">
                    </div><!-- /.owl-slide-item-->
                    <div class="client-carousel__one__item">
                        <img class="client-carousel__one__item__normal" src="assets/images/resources/brand-1-3.png" alt="ienet">
                        <img class="client-carousel__one__item__hover" src="assets/images/resources/brand-1-3-hover.png" alt="ienet">
                    </div><!-- /.owl-slide-item-->
                    <div class="client-carousel__one__item">
                        <img class="client-carousel__one__item__normal" src="assets/images/resources/brand-1-4.png" alt="ienet">
                        <img class="client-carousel__one__item__hover" src="assets/images/resources/brand-1-4-hover.png" alt="ienet">
                    </div><!-- /.owl-slide-item-->
                    <div class="client-carousel__one__item">
                        <img class="client-carousel__one__item__normal" src="assets/images/resources/brand-1-5.png" alt="ienet">
                        <img class="client-carousel__one__item__hover" src="assets/images/resources/brand-1-5-hover.png" alt="ienet">
                    </div><!-- /.owl-slide-item-->
                </div><!-- /.thm-owl__slider -->
            </div><!-- /.container -->
        </div><!-- /.client-carousel -->

        <footer class="main-footer background-black">
            <div class="main-footer__bg background-black" style="background-image: url(assets/images/shapes/footer-bg-1-1.png);"></div>
            <div class="main-footer__shape-one" style="background-image: url(assets/images/resources/footer-shape-1.png);"></div>
            <div class="main-footer__shape-two" style="background-image: url(assets/images/resources/footer-shape-2.png);"></div>
            <!-- /.main-footer__bg -->
            <div class="main-footer__top">
                <div class="container">
                    <div class="main-footer__top__inner">
                        <ul class="list-unstyled main-footer__top__info">
                            <li class="main-footer__top__info__item">
                                <span class="main-footer__top__info__icon"><i class="icon-mail"></i></span>
                                <a href="mailto:info@ienetmail.com">info@ienetmail.com</a>
                            </li>
                            <li class="main-footer__top__info__item">
                                <span class="main-footer__top__info__icon"><i class="icon-maps-and-flags"></i></span>
                                1211 Madison Ave, New York, NY
                            </li>
                        </ul><!-- /.list-unstyled topbar-one__info -->
                        <div class="main-footer__top__right">
                            <div class="main-footer__top__social">

                                <a href="https://facebook.com/">
                                    <i class="fab fa-facebook-f" aria-hidden="true"></i>
                                    <span class="sr-only">Facebook</span>
                                </a>
                                <a href="https://twitter.com/">
                                    <i class="fab fa-twitter" aria-hidden="true"></i>
                                    <span class="sr-only">Twitter</span>
                                </a>
                                <a href="https://instagram.com/">
                                    <i class="fab fa-instagram" aria-hidden="true"></i>
                                    <span class="sr-only">Instagram</span>
                                </a>
                                <a href="https://www.youtube.com/">
                                    <i class="fab fa-youtube" aria-hidden="true"></i>
                                    <span class="sr-only">Youtube</span>
                                </a>
                            </div><!-- /.main-footer__top__social -->
                        </div><!-- /.main-footer__top__right -->
                    </div><!-- /.main-footer__top__inner -->
                </div><!-- /.container -->
            </div><!-- /.main-footer__top -->
            <div class="container">
                <div class="main-footer__middle">
                    <a href="index.html">
                        <img src="assets/images/logo-light.png" height="80" alt="Ienet HTML Template">
                    </a>
                    <form action="#" data-url="MAILCHIMP_FORM_URL" class="footer-widget__newsletter mc-form">
                        <span class="footer-widget__newsletter__icon"><i class="icon-mail"></i></span>
                        <input type="text" name="EMAIL" placeholder="Enter Email Address">
                        <button type="submit" class="ienet-btn"><span>Subscribe Now</span></button>
                        <div class="mc-form__response"></div><!-- /.mc-form__response -->
                    </form><!-- /.footer-widget__newsletter mc-form -->
                    <div class="main-footer__middle__call">
                        <div class="main-footer__middle__call__icon"><span class="icon-telephone"></span></div>
                        <div class="main-footer__middle__call__title">Call Emergency</div>
                        <a class="main-footer__middle__call__text" href="tel:88012365499">+88 0123 654 99</a>
                    </div>
                </div><!-- /.main-footer__middle -->
            </div><!-- /.container -->
            <div class="container">
                <div class="row">
                    <div class="col-md-6 col-xl-3">
                        <div class="footer-widget footer-widget--about">
                            <h2 class="footer-widget__title">About Ienet</h2><!-- /.footer-widget__title -->
                            <p class="footer-widget__text">
                                There are two main types: solar photovoltaic (PV) systems for electricity generation and
                            </p>
                            <a href="about.html" class="ienet-btn"><span>Get In Touch<span class="ienet-btn__icon"><i class="fas fa-chevron-right"></i></span></span></a>
                        </div>
                    </div><!-- /.col-md-6 -->
                    <div class="col-md-6 col-xl-3">
                        <div class="footer-widget footer-widget--links">
                            <h2 class="footer-widget__title">our services</h2><!-- /.footer-widget__title -->
                            <ul class="list-unstyled footer-widget__links">
                                <li><a href="service-d-broadband.html">Fiber & Broadband</a></li>
                                <li><a href="service-d-cyber-security.html">Cyber Security</a></li>
                                <li><a href="service-d-tv.html">Amazon Box TV</a></li>
                                <li><a href="service-d-iptv.html">Smart IPTV</a></li>
                                <li><a href="service-d-connectivity.html">Smart Connectivity</a></li>
                            </ul><!-- /.list-unstyled footer-widget__links -->
                        </div><!-- /.footer-widget -->
                    </div><!-- /.col-md-6 -->
                    <div class="col-md-6 col-xl-3">
                        <div class="footer-widget footer-widget--links">
                            <h2 class="footer-widget__title">useful links</h2><!-- /.footer-widget__title -->
                            <ul class="list-unstyled footer-widget__links">
                                <li><a href="about.html">About Us</a></li>
                                <li><a href="movie.html">Our Movie</a></li>
                                <li><a href="blog-grid-right.html">News & Blog</a></li>
                                <li><a href="faq.html">FAQ</a></li>
                                <li><a href="contact.html">Contacts</a></li>
                            </ul><!-- /.list-unstyled footer-widget__links -->
                        </div><!-- /.footer-widget -->
                    </div><!-- /.col-md-6 -->
                    <div class="col-md-6 col-xl-3">
                        <div class="footer-widget footer-widget--gallery">
                            <h2 class="footer-widget__title">Our Gallery</h2><!-- /.footer-widget__title -->
                            <div class="footer-widget__gallery">
                                <a href="gallery.html" class="footer-widget__gallery__link">
                                    <img src="assets/images/gallery/fg-1.jpg" alt="ienet">
                                </a><!-- /.footer-widget__gallery__link -->
                                <a href="gallery.html" class="footer-widget__gallery__link">
                                    <img src="assets/images/gallery/fg-2.jpg" alt="ienet">
                                </a><!-- /.footer-widget__gallery__link -->
                                <a href="gallery.html" class="footer-widget__gallery__link">
                                    <img src="assets/images/gallery/fg-3.jpg" alt="ienet">
                                </a><!-- /.footer-widget__gallery__link -->
                                <a href="gallery.html" class="footer-widget__gallery__link">
                                    <img src="assets/images/gallery/fg-4.jpg" alt="ienet">
                                </a><!-- /.footer-widget__gallery__link -->
                                <a href="gallery.html" class="footer-widget__gallery__link">
                                    <img src="assets/images/gallery/fg-5.jpg" alt="ienet">
                                </a><!-- /.footer-widget__gallery__link -->
                                <a href="gallery.html" class="footer-widget__gallery__link">
                                    <img src="assets/images/gallery/fg-6.jpg" alt="ienet">
                                </a><!-- /.footer-widget__gallery__link -->
                            </div><!-- /.footer-widget__gallery -->
                        </div>
                    </div><!-- /.col-md-6 -->
                </div><!-- /.row -->
            </div><!-- /.container -->
            <div class="main-footer__bottom">
                <div class="container">
                    <div class="main-footer__bottom__inner">
                        <p class="main-footer__copyright">
                            &copy; Copyright <span class="dynamic-year"></span> by Ienet HTML Template.
                        </p>
                    </div><!-- /.main-footer__inner -->
                </div><!-- /.container -->
            </div><!-- /.main-footer__bottom -->
        </footer><!-- /.main-footer -->

    </div><!-- /.page-wrapper -->



    <div class="mobile-nav__wrapper">
        <div class="mobile-nav__overlay mobile-nav__toggler"></div>
        <!-- /.mobile-nav__overlay -->
        <div class="mobile-nav__content">
            <span class="mobile-nav__close mobile-nav__toggler"><i class="fa fa-times"></i></span>

            <div class="logo-box">
                <a href="index.html" aria-label="logo image"><img src="assets/images/logo-light.png" width="155" alt="" /></a>
            </div>
            <!-- /.logo-box -->
            <div class="mobile-nav__container"></div>
            <!-- /.mobile-nav__container -->

            <ul class="mobile-nav__contact list-unstyled">
                <li>
                    <i class="fa fa-envelope"></i>
                    <a href="mailto:needhelp@ienet.com">needhelp@ienet.com</a>
                </li>
                <li>
                    <i class="fa fa-phone-alt"></i>
                    <a href="tel:666-888-0000">666 888 0000</a>
                </li>
            </ul><!-- /.mobile-nav__contact -->
            <div class="mobile-nav__social">

                <a href="https://facebook.com/">
                    <i class="fab fa-facebook-f" aria-hidden="true"></i>
                    <span class="sr-only">Facebook</span>
                </a>
                <a href="https://twitter.com/">
                    <i class="fab fa-twitter" aria-hidden="true"></i>
                    <span class="sr-only">Twitter</span>
                </a>
                <a href="https://instagram.com/">
                    <i class="fab fa-instagram" aria-hidden="true"></i>
                    <span class="sr-only">Instagram</span>
                </a>
                <a href="https://www.youtube.com/">
                    <i class="fab fa-youtube" aria-hidden="true"></i>
                    <span class="sr-only">Youtube</span>
                </a>
            </div><!-- /.mobile-nav__social -->
        </div>
        <!-- /.mobile-nav__content -->
    </div>
    <!-- /.mobile-nav__wrapper -->
    <div class="search-popup">
        <div class="search-popup__overlay search-toggler"></div>
        <!-- /.search-popup__overlay -->
        <div class="search-popup__content">
            <form role="search" method="get" class="search-popup__form" action="#">
                <input type="text" id="search" placeholder="Search Here..." />
                <button type="submit" aria-label="search submit" class="ienet-btn">
                    <span><i class="icon-search"></i></span>
                </button>
            </form>
        </div>
        <!-- /.search-popup__content -->
    </div>
    <!-- /.search-popup -->
    <!-- Sidebar One Start -->
    <aside class="sidebar-one">
        <div class="sidebar-one__overlay"></div><!-- /.siderbar-ovarlay -->
        <div class="sidebar-one__content">
            <div class="sidebar-one__close"><i class="icon-plus"></i></div><!-- /.siderbar-close -->
            <div class="sidebar-one__logo">
                <a href="index.html" aria-label="logo image"><img src="assets/images/logo-light.png" alt="Ienet HTML" height="80"></a>
            </div><!-- /.sidebar-one__logo-box -->
            <p class="sidebar-one__text">
                Mauris ut enim sit amet lacus ornare ullamcor. Praesent placerat nequ
                puru rhoncu tincidunt odio ultrices. Sed feugiat feugiat felis.
            </p>
            <h4 class="sidebar-one__title">Contact Info:</h4>
            <ul class="sidebar-one__info">
                <li>
                    <span class="fas fa-map-marker-alt"></span>
                    27, Dhaka London City Dhaka, Bangladesh
                </li>
                <li>
                    <span class="fas fa-clock"></span>
                    Mon - Fri: 8.00 am. - 6.00 pm.
                </li>
                <li>
                    <span class="fas fa-envelope"></span>
                    <a href="tel:+9156980036420">+91 5698 0036 420</a>
                </li>
            </ul>
            <div class="sidebar-one__social">

                <a href="https://facebook.com/">
                    <i class="fab fa-facebook-f" aria-hidden="true"></i>
                    <span class="sr-only">Facebook</span>
                </a>
                <a href="https://twitter.com/">
                    <i class="fab fa-twitter" aria-hidden="true"></i>
                    <span class="sr-only">Twitter</span>
                </a>
                <a href="https://instagram.com/">
                    <i class="fab fa-instagram" aria-hidden="true"></i>
                    <span class="sr-only">Instagram</span>
                </a>
                <a href="https://www.youtube.com/">
                    <i class="fab fa-youtube" aria-hidden="true"></i>
                    <span class="sr-only">Youtube</span>
                </a>
            </div><!-- /sidebar-one__socila -->
            <h4 class="sidebar-one__title">Newsletter:</h4>
            <form action="#" data-url="MAILCHIMP_FORM_URL" class="sidebar-one__newsletter mc-form">
                <input type="text" name="EMAIL" placeholder="Email address">
                <button type="submit" class="fas fa-paper-plane">
                    <span class="sr-only">submit</span><!-- /.sr-only -->
                </button>
            </form><!-- /.footer-widget__newsletter mc-form -->
        </div><!-- /.sidebar__content -->
    </aside>
    <!-- Sidebar One Start -->

    <a href="#" data-target="html" class="scroll-to-target scroll-to-top">
        <span class="scroll-to-top__text">back top</span>
        <span class="scroll-to-top__wrapper"><span class="scroll-to-top__inner"></span></span>
    </a>


    <script src="assets/vendors/jquery/jquery-3.7.0.min.js"></script>
    <script src="assets/vendors/bootstrap/js/bootstrap.bundle.min.js"></script>
    <script src="assets/vendors/bootstrap-select/bootstrap-select.min.js"></script>
    <script src="assets/vendors/jarallax/jarallax.min.js"></script>
    <script src="assets/vendors/jquery-ui/jquery-ui.js"></script>
    <script src="assets/vendors/jquery-ajaxchimp/jquery.ajaxchimp.min.js"></script>
    <script src="assets/vendors/jquery-appear/jquery.appear.min.js"></script>
    <script src="assets/vendors/jquery-circle-progress/jquery.circle-progress.min.js"></script>
    <script src="assets/vendors/jquery-magnific-popup/jquery.magnific-popup.min.js"></script>
    <script src="assets/vendors/jquery-validate/jquery.validate.min.js"></script>
    <script src="assets/vendors/nouislider/nouislider.min.js"></script>
    <script src="assets/vendors/tiny-slider/tiny-slider.js"></script>
    <script src="assets/vendors/wnumb/wNumb.min.js"></script>
    <script src="assets/vendors/owl-carousel/js/owl.carousel.min.js"></script>
    <script src="assets/vendors/wow/wow.js"></script>
    <script src="assets/vendors/imagesloaded/imagesloaded.min.js"></script>
    <script src="assets/vendors/isotope/isotope.js"></script>
    <script src="assets/vendors/slick/slick.min.js"></script>
    <script src="assets/vendors/countdown/countdown.min.js"></script>
    <script src="assets/vendors/jquery-circleType/jquery.circleType.js"></script>
    <script src="assets/vendors/jquery-lettering/jquery.lettering.min.js"></script>
    <!-- gsap js -->
    <script src="assets/vendors/gsap/gsap.js"></script>
    <script src="assets/vendors/gsap/scrolltrigger.min.js"></script>
    <script src="assets/vendors/gsap/splittext.min.js"></script>
    <script src="assets/vendors/gsap/ienet-split.js"></script>
    <!-- template js -->
    <script src="assets/js/ienet.js"></script>
</body>


<!-- Mirrored from bracketweb.com/ienet-html-main/index-3.html by HTTrack Website Copier/3.x [XR&CO'2014], Thu, 13 Mar 2025 09:04:23 GMT -->
</html>